@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from typing import Any
+from typing import Collection
 from typing import Dict
 from typing import List
 from typing import Optional
@@ -10,6 +11,11 @@ from typing import Union
 from .exceptions import AttributeMissingError
 from .exceptions import ColumnNotFoundError
 from .exceptions import DuplicateReferenceError
+from .tools import comment_to_dbml
+from .tools import comment_to_sql
+from .tools import indent
+from .tools import note_option_to_dbml
+
 
 
 class SQLOjbect:
@@ -51,6 +57,8 @@ class ReferenceBlueprint:
     Intermediate class for references during parsing. Table and columns are just
     strings at this point, as we can't check their validity until all schema
     is parsed.
+
+    Note: `table2` and `col2` params are technically required (left optional for aesthetics).
     '''
     ONE_TO_MANY = '<'
     MANY_TO_ONE = '>'
@@ -60,9 +68,9 @@ class ReferenceBlueprint:
                  type_: str,
                  name: Optional[str] = None,
                  table1: Optional[str] = None,
-                 col1: Optional[str] = None,
+                 col1: Optional[Union[str, Collection[str]]] = None,
                  table2: Optional[str] = None,
-                 col2: Optional[str] = None,
+                 col2: Optional[Union[str, Collection[str]]] = None,
                  comment: Optional[str] = None,
                  on_update: Optional[str] = None,
                  on_delete: Optional[str] = None):
@@ -77,34 +85,46 @@ class ReferenceBlueprint:
         self.on_delete = on_delete
 
     def __repr__(self):
-        components = [f"ReferenceBlueprint({self.type!r}"]
-        if self.name:
-            components.append(f'name={self.name!r}')
-        if self.table1:
-            components.append(f'table1={self.table1!r}')
-        if self.col1:
-            components.append(f'col1={self.col1!r}')
-        if self.table2:
-            components.append(f'table2={self.table2!r}')
-        if self.col2:
-            components.append(f'col2={self.col2!r}')
-        if self.on_update:
-            components.append(f'on_update={self.on_update!r}')
-        if self.on_delete:
-            components.append(f'on_delete={self.on_delete!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> ReferenceBlueprint('>', table1='t1', col1='c1', table2='t2', col2='c2')
+        <ReferenceBlueprint '>', 't1'.'c1', 't2'.'c2'>
+        >>> ReferenceBlueprint('<', table2='t2', col2='c2')
+        <ReferenceBlueprint '<', 't2'.'c2'>
+        >>> ReferenceBlueprint('>', table1='t1', col1=('c11', 'c12'), table2='t2', col2=['c21', 'c22'])
+        <ReferenceBlueprint '>', 't1'.('c11', 'c12'), 't2'.['c21', 'c22']>
+        '''
+
+        components = [f"<ReferenceBlueprint {self.type!r}"]
+        if self.table1 or self.col1:
+            components.append(f'{self.table1!r}.{self.col1!r}')
+        components.append(f'{self.table2!r}.{self.col2!r}')
+        return ', '.join(components) + '>'
 
     def __str__(self):
-        components = [f"Reference("]
+        '''
+        >>> r1 = ReferenceBlueprint('>', table1='t1', col1='c1', table2='t2', col2='c2')
+        >>> r2 = ReferenceBlueprint('<', table2='t2', col2='c2')
+        >>> r3 = ReferenceBlueprint('>', table1='t1', col1=('c11', 'c12'), table2='t2', col2=('c21', 'c22'))
+        >>> print(r1, r2)
+        ReferenceBlueprint(t1.c1 > t2.c2) ReferenceBlueprint(< t2.c2)
+        >>> print(r3)
+        ReferenceBlueprint(t1[c11, c12] > t2[c21, c22])
+        '''
+
+        components = [f"ReferenceBlueprint("]
         if self.table1:
             components.append(self.table1)
         if self.col1:
-            components.append(f'.{self.col1}')
-        components.append(f' {self.type} ')
-        if self.table2:
-            components.append(self.table2)
-        if self.col2:
+            if isinstance(self.col1, str):
+                components.append(f'.{self.col1} ')
+            else:  # list or tuple
+                components.append(f'[{", ".join(self.col1)}] ')
+        components.append(f'{self.type} ')
+        components.append(self.table2)
+        if isinstance(self.col2, str):
             components.append(f'.{self.col2}')
+        else:  # list or tuple
+            components.append(f'[{", ".join(self.col2)}]')
         return ''.join(components) + ')'
 
 
@@ -123,9 +143,9 @@ class Reference(SQLOjbect):
     def __init__(self,
                  type_: str,
                  table1: Table,
-                 col1: Union[Column, List[Column]],
+                 col1: Union[Column, Collection[Column]],
                  table2: Table,
-                 col2: Union[Column, List[Column]],
+                 col2: Union[Column, Collection[Column]],
                  name: Optional[str] = None,
                  comment: Optional[str] = None,
                  on_update: Optional[str] = None,
@@ -141,32 +161,44 @@ class Reference(SQLOjbect):
         self.on_delete = on_delete
 
     def __repr__(self):
-        components = [
-            f"Reference({self.type!r}",
-            f"{self.table1!r}",
-            f"{self.col1!r}",
-            f"{self.table2!r}",
-            f"{self.col2!r}",
-        ]
-        if self.name:
-            components.append(f'name={self.name!r}')
-        if self.on_update:
-            components.append(f'on_update={self.on_update!r}')
-        if self.on_delete:
-            components.append(f'on_delete={self.on_delete!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> c1 = Column('c1', 'int')
+        >>> c2 = Column('c2', 'int')
+        >>> t1 = Table('t1')
+        >>> t2 = Table('t2')
+        >>> Reference('>', table1=t1, col1=c1, table2=t2, col2=c2)
+        <Reference '>', 't1'.['c1'], 't2'.['c2']>
+        >>> c12 = Column('c12', 'int')
+        >>> c22 = Column('c22', 'int')
+        >>> Reference('<', table1=t1, col1=[c1, c12], table2=t2, col2=(c2, c22))
+        <Reference '<', 't1'.['c1', 'c12'], 't2'.['c2', 'c22']>
+        '''
+
+        components = [f"<Reference {self.type!r}"]
+        components.append(f'{self.table1.name!r}.{[x.name for x in self.col1]!r}')
+        components.append(f'{self.table2.name!r}.{[x.name for x in self.col2]!r}')
+        return ', '.join(components) + '>'
 
     def __str__(self):
+        '''
+        >>> c1 = Column('c1', 'int')
+        >>> c2 = Column('c2', 'int')
+        >>> t1 = Table('t1')
+        >>> t2 = Table('t2')
+        >>> print(Reference('>', table1=t1, col1=c1, table2=t2, col2=c2))
+        Reference(t1[c1] > t2[c2])
+        >>> c12 = Column('c12', 'int')
+        >>> c22 = Column('c22', 'int')
+        >>> print(Reference('<', table1=t1, col1=[c1, c12], table2=t2, col2=(c2, c22)))
+        Reference(t1[c1, c12] < t2[c2, c22])
+        '''
+
         components = [f"Reference("]
-        if self.table1:
-            components.append(self.table1.name)
-        if self.col1:
-            components.append(f'[{", ".join(c.name for c in self.col1)}]')
+        components.append(self.table1.name)
+        components.append(f'[{", ".join(c.name for c in self.col1)}]')
         components.append(f' {self.type} ')
-        if self.table2:
-            components.append(self.table2.name)
-        if self.col2:
-            components.append(f'[{", ".join(c.name for c in self.col2)}]')
+        components.append(self.table2.name)
+        components.append(f'[{", ".join(c.name for c in self.col2)}]')
         return ''.join(components) + ')'
 
     @property
@@ -182,18 +214,19 @@ class Reference(SQLOjbect):
 
         if self.type in (self.MANY_TO_ONE, self.ONE_TO_ONE):
             t1 = self.table1
-            c1 = ', '.join(self.col1)
+            c1 = ', '.join(f'"{c.name}"' for c in self.col1)
             t2 = self.table2
-            c2 = ', '.join(self.col2)
+            c2 = ', '.join(f'"{c.name}"' for c in self.col2)
         else:
             t1 = self.table2
-            c1 = ', '.join(self.col2)
+            c1 = ', '.join(f'"{c.name}"' for c in self.col2)
             t2 = self.table1
-            c2 = ', '.join(self.col1)
+            c2 = ', '.join(f'"{c.name}"' for c in self.col1)
 
-        result = (
-            f'ALTER TABLE "{t1.name}" ADD {c}FOREIGN KEY ("{c1.name}") '
-            f'REFERENCES "{t2.name} ("{c2.name}")'
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += (
+            f'ALTER TABLE "{t1.name}" ADD {c}FOREIGN KEY ({c1}) '
+            f'REFERENCES "{t2.name}" ({c2})'
         )
         if self.on_update:
             result += f' ON UPDATE {self.on_update.upper()}'
@@ -201,6 +234,42 @@ class Reference(SQLOjbect):
             result += f' ON DELETE {self.on_delete.upper()}'
         return result + ';'
 
+    @property
+    def dbml(self):
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += 'Ref'
+        if self.name:
+            result += f' {self.name}'
+
+        if len(self.col1) == 1:
+            col1 = f'"{self.col1[0].name}"'
+        else:
+            names = (f'"{c.name}"' for c in self.col1)
+            col1 = f'({", ".join(names)})'
+
+        if len(self.col2) == 1:
+            col2 = f'"{self.col2[0].name}"'
+        else:
+            names = (f'"{c.name}"' for c in self.col2)
+            col2 = f'({", ".join(names)})'
+
+        options = []
+        if self.on_update:
+            options.append(f'update: {self.on_update}')
+        if self.on_delete:
+            options.append(f'delete: {self.on_delete}')
+
+        options_str = f' [{", ".join(options)}]' if options else ''
+        result += (
+            ' {\n    '
+            f'"{self.table1.name}".{col1} '
+            f'{self.type} '
+            f'"{self.table2.name}".{col2}'
+            f'{options_str}'
+            '\n}'
+        )
+        return result
+
 
 class TableReference(SQLOjbect):
     '''
@@ -225,19 +294,41 @@ class TableReference(SQLOjbect):
         self.on_delete = on_delete
 
     def __repr__(self):
-        components = [f"TableReference({self.col!r}, {self.ref_table!r}, {self.ref_col!r}"]
-        if self.name:
-            components.append(f'name={self.name!r}')
-        if self.on_update:
-            components.append(f'on_update={self.on_update!r}')
-        if self.on_delete:
-            components.append(f'on_delete={self.on_delete!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> c1 = Column('c1', 'int')
+        >>> c2 = Column('c2', 'int')
+        >>> t2 = Table('t2')
+        >>> TableReference(col=c1, ref_table=t2, ref_col=c2)
+        <TableReference ['c1'], 't2'.['c2']>
+        >>> c12 = Column('c12', 'int')
+        >>> c22 = Column('c22', 'int')
+        >>> TableReference(col=[c1, c12], ref_table=t2, ref_col=(c2, c22))
+        <TableReference ['c1', 'c12'], 't2'.['c2', 'c22']>
+        '''
+
+        col_names = [c.name for c in self.col]
+        ref_col_names = [c.name for c in self.ref_col]
+        return f"<TableReference {col_names!r}, {self.ref_table.name!r}.{ref_col_names!r}>"
 
     def __str__(self):
-        cols = '", "'.join(c.name for c in self.col)
-        ref_cols = '", "'.join(c.name for c in self.ref_col)
-        return f"TableReference({cols} -> {self.ref_table.name}[{ref_cols}])"
+        '''
+        >>> c1 = Column('c1', 'int')
+        >>> c2 = Column('c2', 'int')
+        >>> t2 = Table('t2')
+        >>> print(TableReference(col=c1, ref_table=t2, ref_col=c2))
+        TableReference([c1] > t2[c2])
+        >>> c12 = Column('c12', 'int')
+        >>> c22 = Column('c22', 'int')
+        >>> print(TableReference(col=[c1, c12], ref_table=t2, ref_col=(c2, c22)))
+        TableReference([c1, c12] > t2[c2, c22])
+        '''
+
+        components = [f"TableReference("]
+        components.append(f'[{", ".join(c.name for c in self.col)}]')
+        components.append(' > ')
+        components.append(self.ref_table.name)
+        components.append(f'[{", ".join(c.name for c in self.ref_col)}]')
+        return ''.join(components) + ')'
 
     @property
     def sql(self):
@@ -253,7 +344,7 @@ class TableReference(SQLOjbect):
         ref_cols = '", "'.join(c.name for c in self.ref_col)
         result = (
             f'{c}FOREIGN KEY ("{cols}") '
-            f'REFERENCES "{self.ref_table.name} ("{ref_cols}")'
+            f'REFERENCES "{self.ref_table.name}" ("{ref_cols}")'
         )
         if self.on_update:
             result += f' ON UPDATE {self.on_update.upper()}'
@@ -263,16 +354,26 @@ class TableReference(SQLOjbect):
 
 
 class Note:
-    def __init__(self, text: str):
-        self.text = text
+    def __init__(self, text: Any):
+        self.text = str(text) if text else ''
 
     def __str__(self):
+        '''
+        >>> print(Note('Note text'))
+        Note text
+        '''
+
         return self.text
 
     def __bool__(self):
         return bool(self.text)
 
     def __repr__(self):
+        '''
+        >>> Note('Note text')
+        Note('Note text')
+        '''
+
         return f'Note({repr(self.text)})'
 
     @property
@@ -282,6 +383,36 @@ class Note:
         else:
             return ''
 
+    @property
+    def dbml(self):
+        lines = []
+        line = ''
+        for word in self.text.split(' '):
+            if len(line) > 80:
+                lines.append(line)
+                line = ''
+            if '\n' in word:
+                sublines = word.split('\n')
+                for sl in sublines[:-1]:
+                    line += sl
+                    lines.append(line)
+                    line = ''
+                line = sublines[-1] + ' '
+            else:
+                line += f'{word} '
+        if line:
+            lines.append(line)
+        result = 'Note {\n    '
+
+        if len(lines) > 1:
+            lines_str = '\n    '.join(lines)[:-1] + '\n'
+            result += f"'''\n    {lines_str}    '''"
+        else:
+            result += f"'{lines[0][:-1]}'"
+
+        result += '\n}'
+        return result
+
 
 class Column(SQLOjbect):
     '''Class representing table column.'''
@@ -309,7 +440,7 @@ class Column(SQLOjbect):
 
         self.default = default
 
-        self.note = note or Note('')
+        self.note = Note(note)
         self.ref_blueprints = ref_blueprints or []
         for ref in self.ref_blueprints:
             ref.col1 = self.name
@@ -332,8 +463,8 @@ class Column(SQLOjbect):
         Returns inline SQL of the column, which should be a part of table definition:
 
         "id" integer PRIMARY KEY AUTOINCREMENT
-
         '''
+
         self.check_attributes_for_sql()
         components = [f'"{self.name}"', str(self.type)]
         if self.pk:
@@ -346,39 +477,60 @@ class Column(SQLOjbect):
             components.append('NOT NULL')
         if self.default is not None:
             components.append('DEFAULT ' + str(self.default))
+
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += ' '.join(components)
+        return result
+
+    @property
+    def dbml(self):
+        def default_to_str(val: str) -> str:
+            if isinstance(val, str):
+                if val.lower() in ('null', 'true', 'false'):
+                    return val.lower()
+                elif val.startswith('(') and val.endswith(')'):
+                    return f'`{val[1:-1]}`'
+                else:
+                    return f"'{val}'"
+            else:  # int or float or bool
+                return val
+
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'"{self.name}" {self.type}'
+
+        options = []
+        if self.pk:
+            options.append('pk')
+        if self.autoinc:
+            options.append('increment')
+        if self.default:
+            options.append(f'default: {default_to_str(self.default)}')
+        if self.unique:
+            options.append('unique')
+        if self.not_null:
+            options.append('not null')
         if self.note:
-            components.append(self.note.sql)
-        return ' '.join(components)
+            options.append(note_option_to_dbml(self.note))
+
+        if options:
+            result += f' [{", ".join(options)}]'
+        return result
 
     def __repr__(self):
-        components = [f"Column({self.name!r}, {self.type!r}"]
-        if self.unique:
-            components.append(f'unique=True')
-        if self.not_null:
-            components.append(f'not_null=True')
-        if self.pk:
-            components.append(f'pk=True')
-        if self.autoinc:
-            components.append(f'autoinc=True')
-        if self.default:
-            components.append(f'default={self.default!r}')
-        if self.note:
-            components.append(f'note={self.note!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> Column('name', 'VARCHAR2')
+        <Column 'name', 'VARCHAR2'>
+        '''
+        type_name = self.type if isinstance(self.type, str) else self.type.name
+        return f'<Column {self.name!r}, {type_name!r}>'
 
     def __str__(self):
-        components = [f"Column({self.name} {self.type}"]
-        if self.unique:
-            components.append(f'unique')
-        if self.not_null:
-            components.append(f'not_null')
-        if self.pk:
-            components.append(f'pk')
-        if self.autoinc:
-            components.append(f'autoincrement')
-        if self.default:
-            components.append(f'default={self.default!r}')
-        return ' '.join(components) + ')'
+        '''
+        >>> print(Column('name', 'VARCHAR2'))
+        name[VARCHAR2]
+        '''
+
+        return f'{self.name}[{self.type}]'
 
 
 class Index(SQLOjbect):
@@ -402,38 +554,34 @@ class Index(SQLOjbect):
         self.unique = unique
         self.type = type_
         self.pk = pk
-        self.note = note or Note('')
+        self.note = Note(note)
         self.comment = comment
 
     def __repr__(self):
-        components = [f"Index({self.subject_names!r}"]
-        if self.name:
-            components.append(f'name={self.name!r}')
-        if self.unique:
-            components.append(f'unique=True')
-        if self.type:
-            components.append(f'type_={self.type!r}')
-        if self.pk:
-            components.append(f'pk=True')
-        if self.note:
-            components.append(f'note_={self.note!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> Index(['name', 'type'])
+        <Index None, ['name', 'type']>
+        >>> t = Table('t')
+        >>> Index(['name', 'type'], table=t)
+        <Index 't', ['name', 'type']>
+        '''
+
+        table_name = self.table.name if self.table else None
+        return f"<Index {table_name!r}, {self.subject_names!r}>"
+
 
     def __str__(self):
-        components = [f"Index("]
-        if len(self.subjects) == 1:
-            components[0] += self.subjects[0]
-        else:
-            components[0] += '(' + ', '.join(self.subjects) + ')'
-        if self.name:
-            components.append(f'{self.name!r}')
-        if self.unique:
-            components.append(f'unique')
-        if self.type:
-            components.append(f'{self.type}')
-        if self.pk:
-            components.append(f'pk')
-        return ' '.join(components) + ')'
+        '''
+        >>> print(Index(['name', 'type']))
+        Index([name, type])
+        >>> t = Table('t')
+        >>> print(Index(['name', 'type'], table=t))
+        Index(t[name, type])
+        '''
+
+        table_name = self.table.name if self.table else ''
+        subjects = ', '.join(s for s in self.subject_names)
+        return f"Index({table_name}[{subjects}])"
 
     @property
     def sql(self):
@@ -452,7 +600,9 @@ class Index(SQLOjbect):
         self.check_attributes_for_sql()
         keys = ', '.join(f'"{key.name}"' if isinstance(key, Column) else key for key in self.subjects)
         if self.pk:
-            return f'PRIMARY KEY ({keys})'
+            result = comment_to_sql(self.comment) if self.comment else ''
+            result += f'PRIMARY KEY ({keys})'
+            return result
 
         components = ['CREATE']
         if self.unique:
@@ -464,9 +614,39 @@ class Index(SQLOjbect):
         if self.type:
             components.append(f'USING {self.type.upper()}')
         components.append(f'({keys})')
-        result = ' '.join(components) + ';'
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += ' '.join(components) + ';'
+        return result
+
+    @property
+    def dbml(self):
+        def subject_to_str(val: str) -> str:
+            if val.startswith('(') and val.endswith(')'):
+                return f'`{val[1:-1]}`'
+            else:
+                return val
+
+        result = comment_to_dbml(self.comment) if self.comment else ''
+
+        if len(self.subject_names) > 1:
+            result += f'({", ".join(subject_to_str(sn) for sn in self.subject_names)})'
+        else:
+            result += subject_to_str(self.subject_names[0])
+
+        options = []
+        if self.name:
+            options.append(f"name: '{self.name}'")
+        if self.pk:
+            options.append('pk')
+        if self.unique:
+            options.append('unique')
+        if self.type:
+            options.append(f'type: {self.type}')
         if self.note:
-            result += f' {self.note.sql}'
+            options.append(note_option_to_dbml(self.note))
+
+        if options:
+            result += f' [{", ".join(options)}]'
         return result
 
 
@@ -487,7 +667,7 @@ class Table(SQLOjbect):
         self.indexes: List[Index] = []
         self.column_dict: Dict[str, Column] = {}
         self.alias = alias if alias else None
-        self.note = note or Note('')
+        self.note = Note(note)
         self.header_color = header_color
         self.refs = refs or []
         self.comment = comment
@@ -542,23 +722,24 @@ class Table(SQLOjbect):
         return iter(self.columns)
 
     def __repr__(self):
-        components = [f"Table({self.name!r}, {self.columns!r}"]
-        if self.alias:
-            components.append(f'alias={self.alias!r}')
-        if self.indexes:
-            components.append(f'indexes={self.indexes!r}')
-        if self.note:
-            components.append(f'note={self.note!r}')
-        if self.header_color:
-            components.append(f'header_color={self.header_color!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> table = Table('customers')
+        >>> table
+        <Table 'customers'>
+        '''
+
+        return f'<Table {self.name!r}>'
 
     def __str__(self):
-        components = [f"Table {self.name}"]
-        if self.alias:
-            components.append(f' as {self.alias} ')
-        components.append('(' + ', '.join(c.name for c in self.columns))
-        return ''.join(components) + ')'
+        '''
+        >>> table = Table('customers')
+        >>> table.add_column(Column('id', 'INTEGER'))
+        >>> table.add_column(Column('name', 'VARCHAR2'))
+        >>> print(table)
+        customers(id, name)
+        '''
+
+        return f'{self.name}({", ".join(c.name for c in self.columns)})'
 
     @property
     def sql(self):
@@ -577,44 +758,91 @@ class Table(SQLOjbect):
         '''
         self.check_attributes_for_sql()
         components = [f'CREATE TABLE "{self.name}" (']
-        if self.note:
-            components.append(f'  {self.note.sql}')
         body = []
-        body.extend('  ' + c.sql for c in self.columns)
-        body.extend('  ' + i.sql for i in self.indexes if i.pk)
-        body.extend('  ' + r.sql for r in self.refs)
+        body.extend(indent(c.sql, 2) for c in self.columns)
+        body.extend(indent(i.sql, 2) for i in self.indexes if i.pk)
+        body.extend(indent(r.sql, 2) for r in self.refs)
         components.append(',\n'.join(body))
-        components.append(');\n')
-        components.extend(i.sql + '\n' for i in self.indexes if not i.pk)
-        return '\n'.join(components)
+        components.append(');')
+        components.extend('\n' + i.sql for i in self.indexes if not i.pk)
+
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += '\n'.join(components)
+
+        if self.note:
+            quoted_note = f"'{self.note.text}'"
+            note_sql = f'COMMENT ON TABLE "{self.name}" IS {quoted_note};'
+            result += f'\n\n{note_sql}'
+
+        for col in self.columns:
+            if col.note:
+                quoted_note = f"'{col.note.text}'"
+                note_sql = f'COMMENT ON COLUMN "{self.name}"."{col.name}" IS {quoted_note};'
+                result += f'\n\n{note_sql}'
+        return result
+
+    @property
+    def dbml(self):
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'Table "{self.name}" '
+        if self.alias:
+            result += f'as "{self.alias}" '
+        result += '{\n'
+        columns_str = '\n'.join(c.dbml for c in self.columns)
+        result += indent(columns_str) + '\n'
+        if self.note:
+            result += indent(self.note.dbml) + '\n'
+        if self.indexes:
+            result += '\n    indexes {\n'
+            indexes_str = '\n'.join(i.dbml for i in self.indexes)
+            result += indent(indexes_str, 8) + '\n'
+            result += '    }\n'
+
+        result += '}'
+        return result
 
 
 class EnumItem:
-    '''Single enum item. Does not translate into SQL'''
+    '''Single enum item'''
 
     def __init__(self,
                  name: str,
                  note: Optional[Note] = None,
                  comment: Optional[str] = None):
         self.name = name
-        self.note = note or Note('')
+        self.note = Note(note)
         self.comment = comment
 
     def __repr__(self):
-        components = [f'EnumItem({self.name!r}']
-        if self.note:
-            components.append(f'note={self.note!r}')
-        return ', '.join(components) + ')'
+        '''
+        >>> EnumItem('en-US')
+        <EnumItem 'en-US'>
+        '''
+
+        return f'<EnumItem {self.name!r}>'
 
     def __str__(self):
+        '''
+        >>> print(EnumItem('en-US'))
+        en-US
+        '''
+
         return self.name
 
     @property
     def sql(self):
-        components = [f"'{self.name}',"]
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += f"'{self.name}',"
+        return result
+
+    @property
+    def dbml(self):
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'"{self.name}"'
         if self.note:
-            components.append(self.note.sql)
-        return ' '.join(components)
+            result += f' [{note_option_to_dbml(self.note)}]'
+        return result
+
 
 
 class Enum(SQLOjbect):
@@ -638,12 +866,26 @@ class Enum(SQLOjbect):
         return iter(self.items)
 
     def __repr__(self):
-        return f'Enum({self.name!r}, {self.items!r})'
+        '''
+        >>> en = EnumItem('en-US')
+        >>> ru = EnumItem('ru-RU')
+        >>> Enum('languages', [en, ru])
+        <Enum 'languages', ['en-US', 'ru-RU']>
+        '''
+
+        item_names = [i.name for i in self.items]
+        classname = self.__class__.__name__
+        return f'<{classname} {self.name!r}, {item_names!r}>'
 
     def __str__(self):
-        return (
-            f'Enum {self.name} (' + ', '.join(str(i) for i in self.items) + ')'
-        )
+        '''
+        >>> en = EnumItem('en-US')
+        >>> ru = EnumItem('ru-RU')
+        >>> print(Enum('languages', [en, ru]))
+        languages
+        '''
+
+        return self.name
 
     @property
     def sql(self):
@@ -659,21 +901,36 @@ class Enum(SQLOjbect):
 
         '''
         self.check_attributes_for_sql()
-        return f'CREATE TYPE "{self.name}" AS ENUM (\n' +\
-               '\n'.join(f'  {i.sql}' for i in self.items) +\
-               '\n);'
+        result = comment_to_sql(self.comment) if self.comment else ''
+        result += f'CREATE TYPE "{self.name}" AS ENUM (\n'
+        result +='\n'.join(f'{indent(i.sql, 2)}' for i in self.items)
+        result += '\n);'
+        return result
+
+    @property
+    def dbml(self):
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'Enum "{self.name}" {{\n'
+        items_str = '\n'.join(i.dbml for i in self.items)
+        result += indent(items_str)
+        result += '\n}'
+        return result
+
 
 
 class EnumType(Enum):
     '''
     Enum object, intended to be put in the `type` attribute of a column.
+
+    >>> en = EnumItem('en-US')
+    >>> ru = EnumItem('ru-RU')
+    >>> EnumType('languages', [en, ru])
+    <EnumType 'languages', ['en-US', 'ru-RU']>
+    >>> print(_)
+    languages
     '''
 
-    def __repr__(self):
-        return f'EnumType({self.name!r}, {self.items!r})'
-
-    def __str__(self):
-        return self.name
+    pass
 
 
 class TableGroup:
@@ -692,7 +949,19 @@ class TableGroup:
         self.comment = comment
 
     def __repr__(self):
-        return f'TableGroup({self.name!r}, {self.items!r})'
+        """
+        >>> tg = TableGroup('mygroup', ['t1', 't2'])
+        >>> tg
+        <TableGroup 'mygroup', ['t1', 't2']>
+        >>> t1 = Table('t1')
+        >>> t2 = Table('t2')
+        >>> tg.items = [t1, t2]
+        >>> tg
+        <TableGroup 'mygroup', ['t1', 't2']>
+        """
+
+        items = [i if isinstance(i, str) else i.name for i in self.items]
+        return f'<TableGroup {self.name!r}, {items!r}>'
 
     def __getitem__(self, key) -> str:
         return self.items[key]
@@ -700,6 +969,21 @@ class TableGroup:
     def __iter__(self):
         return iter(self.items)
 
+    @property
+    def dbml(self):
+        def item_to_str(val: Union[str, Table]) -> str:
+            if isinstance(val, Table):
+                return val.name
+            else:
+                return val
+
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'TableGroup {self.name} {{\n'
+        for i in self.items:
+            result += f'    {item_to_str(i)}\n'
+        result += '}'
+        return result
+
 
 class Project:
     def __init__(self,
@@ -709,13 +993,30 @@ class Project:
                  comment: Optional[str] = None):
         self.name = name
         self.items = items
-        self.note = note or Note('')
+        self.note = Note(note)
         self.comment = comment
 
     def __repr__(self):
-        components = [f'Project({self.name!r}']
+        """
+        >>> Project('myproject')
+        <Project 'myproject'>
+        """
+
+        return f'<Project {self.name!r}>'
+
+    @property
+    def dbml(self):
+        result = comment_to_dbml(self.comment) if self.comment else ''
+        result += f'Project {self.name} {{\n'
         if self.items:
-            components.append(f'items={self.items!r}')
+            items_str = ''
+            for k, v in self.items.items():
+                if '\n' in v:
+                    items_str += f"{k}: '''{v}'''\n"
+                else:
+                    items_str += f"{k}: '{v}'\n"
+            result += indent(items_str[:-1]) + '\n'
         if self.note:
-            components.append(f'note={self.note!r}')
-        return ', '.join(components) + ')'
+            result += indent(self.note.dbml) + '\n'
+        result += '}'
+        return result
