@@ -1,8 +1,13 @@
 import pyparsing as pp
-from pydbml.definitions.generic import name
-from pydbml.definitions.common import _, _c, c, n
+
 from pydbml.classes import ReferenceBlueprint
 
+from .common import _
+from .common import _c
+from .common import c
+from .common import n
+from .generic import name
+
 pp.ParserElement.setDefaultWhitespaceChars(' \t\r')
 
 relation = pp.oneOf("> - <")
@@ -21,11 +26,11 @@ def parse_inline_relation(s, l, t):
 ref_inline.setParseAction(parse_inline_relation)
 
 on_option = (
-    pp.CaselessLiteral('no action') |
-    pp.CaselessLiteral('restrict') |
-    pp.CaselessLiteral('cascade') |
-    pp.CaselessLiteral('set null') |
-    pp.CaselessLiteral('set default')
+    pp.CaselessLiteral('no action')
+    | pp.CaselessLiteral('restrict')
+    | pp.CaselessLiteral('cascade')
+    | pp.CaselessLiteral('set null')
+    | pp.CaselessLiteral('set default')
 )
 update = pp.CaselessLiteral("update:").suppress() + _ + on_option
 delete = pp.CaselessLiteral("delete:").suppress() + _ + on_option
@@ -33,13 +38,13 @@ delete = pp.CaselessLiteral("delete:").suppress() + _ + on_option
 ref_setting = _ + (update('update') | delete('delete')) + _
 
 ref_settings = (
-    '[' +
-    ref_setting +
-    (
-        ',' +
-        ref_setting
-    )[...] +
-    ']' + c
+    '['
+    + ref_setting
+    + (
+        ','
+        + ref_setting
+    )[...]
+    + ']' + c
 )
 
 
@@ -59,24 +64,37 @@ def parse_ref_settings(s, l, t):
 
 ref_settings.setParseAction(parse_ref_settings)
 
-ref_body = (
-    name('table1') -
-    '.' -
-    name('field1') -
-    relation('type') -
-    name('table2') -
-    '.' -
-    name('field2') + c +
-    ref_settings('settings')[0, 1]
+composite_name = (
+    '(' + pp.White()[...]
+    - name + pp.White()[...]
+    + (
+        pp.White()[...] + ","
+        + pp.White()[...] + name
+        + pp.White()[...]
+    )[...]
+    + ')'
 )
+name_or_composite = name | pp.Combine(composite_name)
+
+ref_body = (
+    name('table1')
+    - '.'
+    - name_or_composite('field1')
+    - relation('type')
+    - name('table2')
+    - '.'
+    - name_or_composite('field2') + c
+    + ref_settings('settings')[0, 1]
+)
+
 
 ref_short = _c + pp.CaselessLiteral('ref') + name('name')[0, 1] + ':' - ref_body
 ref_long = _c + (
-    pp.CaselessLiteral('ref') + _ +
-    name('name')[0, 1] + _ +
-    '{' + _ -
-    ref_body + _ -
-    '}'
+    pp.CaselessLiteral('ref') + _
+    + name('name')[0, 1] + _
+    + '{' + _
+    - ref_body + _
+    - '}'
 )
 
 
