@@ -267,4 +267,14 @@ class PyDBMLParseResults:
         '''Returs SQL of the parsed results'''
 
         components = (i.sql for i in (*self.enums, *self.tables))
-        return '\n'.join(components)
+        return '\n\n'.join(components)
+
+    @property
+    def dbml(self):
+        '''Generates DBML code out of parsed results'''
+        items = [self.project] if self.project else []
+        items.extend((*self.tables, *self.refs, *self.enums, *self.table_groups))
+        components = (
+            i.dbml for i in items
+        )
+        return '\n\n'.join(components)
